;; Generated package description from flymake-proselint.el  -*- no-byte-compile: t -*-
(define-package "flymake-proselint" "0.2.3.0.20211026.45924" "Flymake backend for proselint" '((emacs "26.1")) :authors '(("Manuel Uberti" . "manuel.uberti@inventati.org")) :maintainer '("Manuel Uberti" . "manuel.uberti@inventati.org") :keywords '("convenience") :url "https://github.com/manuel-uberti/flymake-proselint")
